@@ -9,22 +9,22 @@
 #define MAX_HTTPBUFFER 8192
 
 #if defined (__linux__)
-#define SALT "$1$Snare$"
+	#define SALT "$1$Snare$"
 #elif defined __sgi
-// IRIX
-#define SALT "Sn"
+	// IRIX
+	#define SALT "Sn"
 #else
-// Solaris
-#define SALT "$1"
+	// Solaris
+	#define SALT "$1"
 #endif
 
 void decodeurl(char *pEncoded);
 int hex2int(char *pChars);
 int InitWebServer(unsigned short, char *, char *);
-int StartThread();
-int ListenThread();
+int StartThread(void);
+int ListenThread(void);
 int HandleConnect(void);
-int CloseWebServer();
+int CloseWebServer(void);
 void RequestAuth(char *HTTPOutputBuffer, int size);
 int MatchAuth(char *AuthStart);
 int AuthorisedSource(char *address);
